# Asp - Aspect Oriented Programming for Python

An Aspect Oriented Programming Library for Python.

## Contributors

* Tom Wallis<br/>
  School of Computing Science, University of Glasgow<br/>
  GitHub ID: probablytom
  [twallisgm@googlemail.com](mailto:twallisgm@googlemail.com)

* Tim Storer<br/>
  School of Computing Science, University of Glasgow<br/>
  GitHub ID: twsswt
  [timothy.storer@glagow.ac.uk](mailto:timothy.storer@glagow.ac.uk)

## Overview

Asp is a library for applying aspects (cross cutting concerns) to Python modules at runtime.

## Examples

Todo